==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/TASKPRICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TASKPRICEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TASKPRICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKPRICEID_Type", propOrder = {
    "taskcode",
    "description",
    "taskrevision",
    "organizationid"
})
public class TASKPRICEID_Type {

    @XmlElement(name = "TASKCODE", required = true)
    protected String taskcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlElement(name = "TASKREVISION")
    protected long taskrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Obtient la valeur de la propriété taskcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTASKCODE() {
        return taskcode;
    }

    /**
     * Définit la valeur de la propriété taskcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTASKCODE(String value) {
        this.taskcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété taskrevision.
     * 
     */
    public long getTASKREVISION() {
        return taskrevision;
    }

    /**
     * Définit la valeur de la propriété taskrevision.
     * 
     */
    public void setTASKREVISION(long value) {
        this.taskrevision = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/TASKPRICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKPRICEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TASKPRICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKPRICEID_Type", propOrder = {
    "taskcode",
    "description",
    "taskrevision",
    "organizationid"
})
public class TASKPRICEID_Type {

    @XmlElement(name = "TASKCODE", required = true)
    protected String taskcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlElement(name = "TASKREVISION")
    protected long taskrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Gets the value of the taskcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTASKCODE() {
        return taskcode;
    }

    /**
     * Sets the value of the taskcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTASKCODE(String value) {
        this.taskcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the taskrevision property.
     * 
     */
    public long getTASKREVISION() {
        return taskrevision;
    }

    /**
     * Sets the value of the taskrevision property.
     * 
     */
    public void setTASKREVISION(long value) {
        this.taskrevision = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}
